Date: 01 4, 2002 12:55:01 PM

# pnup

## Purpose

Fetch the parent of a parse tree node if one exists. Only the leftmost parse tree node in a list has a parent.

## Syntax

returnedPnode = pnup(aPnode)

returnedPnode - type: pnode
aPnode - type: pnode

## Returns

## Remarks

Pnup is a primitive that does not fetch the parent. (An NLP++ pnparent function is called for or can be written by the user.)

## Example

## See Also

pndown, pnsingletdown, pnprev, pnnext, Parse Tree Functions